/*
Copyright (c) 2007 Adan Scotney

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
// font.cpp : drawing code
#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
using namespace std;
extern SDL_Surface *screen;

#define BUF_SIZE	1024

int ttf_printf(TTF_Font *font, int x, int y, SDL_Color colour, 
				const char* input, ...) {
	va_list sc;						// Scancodes
	char buffer[BUF_SIZE];			// Buffer to store final string
	strcpy(buffer, input);
	
	va_start(sc, input);			// Variable arguments after 'input'
	vsprintf(buffer, buffer, sc);	// Parse string
	va_end(sc);						// Clean up variable arguments
	
	SDL_Surface *tempsfc = TTF_RenderUTF8_Blended(font, buffer, colour);
	SDL_Rect dest_rect;				// Destination on-screen
	dest_rect.x = x;
	dest_rect.y = y;
	SDL_BlitSurface(tempsfc, NULL, screen, &dest_rect);
	SDL_FreeSurface(tempsfc);		// Free temporary text surface
}

int ttf_printf_centre(TTF_Font *font, SDL_Color colour, 
						const char* input, ...) {
	va_list sc;						// Scancodes
	char buffer[BUF_SIZE];			// Buffer to store final string
	strcpy(buffer, input);
	
	va_start(sc, input);			// Variable arguments after 'input'
	vsprintf(buffer, buffer, sc);	// Parse string
	va_end(sc);						// Clean up variable arguments
	
	SDL_Surface *tempsfc = TTF_RenderUTF8_Blended(font, buffer, colour);
	SDL_Rect dest_rect;				// Destination on-screen
	dest_rect.x = (screen->w/2)-(tempsfc->w/2);
	dest_rect.y = (screen->h/2)-(tempsfc->h/2);
	SDL_BlitSurface(tempsfc, NULL, screen, &dest_rect);
	SDL_FreeSurface(tempsfc);		// Free temporary text surface
}

int ttf_printf_centrex(TTF_Font *font, int y, SDL_Color colour, 
						const char* input, ...) {
	va_list sc;						// Scancodes
	char buffer[BUF_SIZE];			// Buffer to store final string
	strcpy(buffer, input);
	
	va_start(sc, input);			// Variable arguments after 'input'
	vsprintf(buffer, buffer, sc);	// Parse string
	va_end(sc);						// Clean up variable arguments
	
	SDL_Surface *tempsfc = TTF_RenderUTF8_Blended(font, buffer, colour);
	SDL_Rect dest_rect;				// Destination on-screen
	dest_rect.x = (screen->w/2)-(tempsfc->w/2);
	dest_rect.y = y;
	SDL_BlitSurface(tempsfc, NULL, screen, &dest_rect);
	SDL_FreeSurface(tempsfc);		// Free temporary text surface
}

int ttf_printf_centrey(TTF_Font *font, int x, SDL_Color colour, 
						const char* input, ...) {
	va_list sc;						// Scancodes
	char buffer[BUF_SIZE];			// Buffer to store final string
	strcpy(buffer, input);
	
	va_start(sc, input);			// Variable arguments after 'input'
	vsprintf(buffer, buffer, sc);	// Parse string
	va_end(sc);						// Clean up variable arguments
	
	SDL_Surface *tempsfc = TTF_RenderUTF8_Blended(font, buffer, colour);
	SDL_Rect dest_rect;				// Destination on-screen
	dest_rect.x = x;
	dest_rect.y = (screen->h/2)-(tempsfc->h/2);
	SDL_BlitSurface(tempsfc, NULL, screen, &dest_rect);
	SDL_FreeSurface(tempsfc);		// Free temporary text surface
}
